Struct parse_mediawiki_sql::field_types::NotNan [−][src]
#[repr(transparent)]pub struct NotNan<T>(_);
The type used for float fields that are never NaN. A wrapper around Floats providing an implementation of Ord and Hash.
A NaN value cannot be stored in this type.
Implementations
impl<T> NotNan<T>[src]
impl<T> NotNan<T>[src]The type used for float fields that are never NaN.
pub const unsafe fn unchecked_new(val: T) -> NotNan<T>[src]
pub const unsafe fn unchecked_new(val: T) -> NotNan<T>[src]Create a NotNan value from a value that is guaranteed to not be NaN
Safety
Behaviour is undefined if val is NaN
impl<T> NotNan<T> where
T: Float, [src]
impl<T> NotNan<T> where
T: Float, [src]The type used for float fields that are never NaN.
pub fn new(val: T) -> Result<NotNan<T>, FloatIsNan>[src]
pub fn new(val: T) -> Result<NotNan<T>, FloatIsNan>[src]Create a NotNan value.
Returns Err if val is NaN
pub fn into_inner(self) -> T[src]
pub fn into_inner(self) -> T[src]Get the value out.